Changelog
=========

Version 0.1.0
*************

* fix ldap auth module if using tls
* add notification mechanizism for add/delete records
* remove ugly status pages
* adding some unit tests

Version 0.0.1
*************

* first release 
